@@ -74,6 +74,10 @@
 
 #define GPM_TABS_DIR			GPM_PREFS_DIR "/editor/tabs"
 #define GPM_TABS_SIZE			GPM_TABS_DIR "/tabs_size"
+#define GPM_INSERT_SPACES		GPM_TABS_DIR "/insert_spaces"
+
+#define GPM_AUTO_INDENT_DIR		GPM_PREFS_DIR "/editor/auto_indent"
+#define GPM_AUTO_INDENT			GPM_AUTO_INDENT_DIR "/auto_indent"
 
 #define GPM_LINE_NUMBERS_DIR		GPM_PREFS_DIR "/editor/line_numbers"
 #define GPM_DISPLAY_LINE_NUMBERS 	GPM_LINE_NUMBERS_DIR "/display_line_numbers"
@@ -134,6 +138,9 @@
 #define GPM_DEFAULT_WRAP_MODE		"GTK_WRAP_WORD"
 
 #define GPM_DEFAULT_TABS_SIZE		8
+#define GPM_DEFAULT_INSERT_SPACES	0 /* FALSE */
+
+#define GPM_DEFAULT_AUTO_INDENT		0 /* FALSE */
 
 #define GPM_DEFAULT_DISPLAY_LINE_NUMBERS 0 /* FALSE */
 
@@ -887,6 +894,16 @@ DEFINE_INT_PREF (tabs_size,
 		 GPM_TABS_SIZE, 
 		 GPM_DEFAULT_TABS_SIZE);
 
+/* Insert spaces */
+DEFINE_BOOL_PREF (insert_spaces, 
+		  GPM_INSERT_SPACES, 
+		  GPM_DEFAULT_INSERT_SPACES)
+
+/* Auto indent */
+DEFINE_BOOL_PREF (auto_indent, 
+		  GPM_AUTO_INDENT, 
+		  GPM_DEFAULT_AUTO_INDENT)
+
 /* Display line numbers */
 DEFINE_BOOL_PREF (display_line_numbers, 
 		  GPM_DISPLAY_LINE_NUMBERS, 
@@ -916,8 +933,13 @@ gedit_prefs_manager_get_toolbar_buttons_style (void)
 	{
 		if (strcmp (str, "GEDIT_TOOLBAR_ICONS_AND_TEXT") == 0)
 			res = GEDIT_TOOLBAR_ICONS_AND_TEXT;
-		else
-			res = GEDIT_TOOLBAR_SYSTEM;
+		else 
+		{
+			if (strcmp (str, "GEDIT_TOOLBAR_ICONS_BOTH_HORIZ") == 0)
+				res = GEDIT_TOOLBAR_ICONS_BOTH_HORIZ;
+			else
+				res = GEDIT_TOOLBAR_SYSTEM;
+		}
 	}
 
 	g_free (str);
@@ -943,6 +965,9 @@ gedit_prefs_manager_set_toolbar_buttons_style (GeditToolbarSetting tbs)
 			str = "GEDIT_TOOLBAR_ICONS_AND_TEXT";
 			break;
 
+	        case GEDIT_TOOLBAR_ICONS_BOTH_HORIZ:
+			str = "GEDIT_TOOLBAR_ICONS_BOTH_HORIZ";
+			break;
 		default: /* GEDIT_TOOLBAR_SYSTEM */
 			str = "GEDIT_TOOLBAR_SYSTEM";
 	}
